import fs from 'fs'
import path from 'path'
import { fileURLToPath, URL } from 'url'

import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'
import checker from 'vite-plugin-checker'

export default defineConfig(({ mode }) => {
  return {
    base: mode === 'prod' ? 'https://webapp-pub.ezijing.com/website/prod/sass/' : '/',
    plugins: [checker({ vueTsc: true, eslint: { lintCommand: 'eslint "./src/**/*.{vue,js,jsx,ts,tsx}"' } }), vue()],
    server: {
      open: true,
      host: 'dev.ezijing.com',
      https: {
        key: fs.readFileSync(path.join(__dirname, './https/dev.ezijing.com.key')),
        cert: fs.readFileSync(path.join(__dirname, './https/dev.ezijing.com.pem'))
      }
    },
    resolve: {
      alias: {
        '@': fileURLToPath(new URL('./src', import.meta.url))
      }
    },
    css: {
      // 禁用SASS警告提醒
      preprocessorOptions: { scss: { charset: false } }
    }
  }
})
